@@ -24,6 +24,8 @@ our @EXPORT_OK = @EXPORT ;
 use strict ;
 no warnings ;
 
+use XML::Smart::Entity qw(_add_basic_entity) ;
+
 ########
 # DATA #
 ########
@@ -451,43 +453,6 @@ sub _check_key {
   return( $_[0] ) ;
 }
 
-#######################
-# _PARSE_BASIC_ENTITY #
-#######################
-
-sub _parse_basic_entity {
-  $_[0] =~ s/&lt;/</gs ;
-  $_[0] =~ s/&gt;/>/gs ;
-  $_[0] =~ s/&amp;/&/gs ;
-  $_[0] =~ s/&apos;/'/gs ;
-  $_[0] =~ s/&quot;/"/gs ;
-  
-  $_[0] =~ s/&#(\d+);/ $1 > 255 ? pack("U",$1) : pack("C",$1)/egs ;
-  $_[0] =~ s/&#x([a-fA-F\d]+);/pack("U",hex($1))/egs ;
-  
-  return( $_[0] ) ;
-}
-
-#####################
-# _ADD_BASIC_ENTITY #
-#####################
-
-sub _add_basic_entity {
-  $_[0] =~ s/(&(?:\w+;)?)/{_is_amp($1) or $1}/sgex ;
-  $_[0] =~ s/</&lt;/gs ;
-  $_[0] =~ s/>/&gt;/gs ;
-  return( $_[0] ) ;
-}
-
-###########
-# _IS_AMP #
-###########
-
-sub _is_amp {
-  if ($_[0] eq '&') { return( '&amp;' ) ;}
-  return( undef ) ;
-}
-
 ##############
 # _ADD_QUOTE #
 ##############
